package com.example.fieldagent.data.network

import android.app.Activity
import android.content.Intent
import android.util.Log
import androidx.appcompat.app.AlertDialog
import com.example.fieldagent.data.network.responseUtil.AppError
import com.example.fieldagent.R
import com.example.fieldagent.ui.login.LoginActivity

object ApisRespHandler {

    private var alertDialog: AlertDialog.Builder? = null

    fun handleError(error: AppError?, activity: Activity,) {
        error ?: return


        when (error) {
            is AppError.ApiError -> {
                if (alertDialog == null)
                    errorMessage(activity, error.message,error.statusCode)
            }

            is AppError.ApiUnauthorized -> {
                if (alertDialog == null)
                    errorMessage(activity, error.message,401)
            }

            is AppError.ApiAccountBlock -> {

            }

            is AppError.ApiAccountRuleChanged -> {

            }

            is AppError.ApiFailure -> {
                if (alertDialog == null) {
                    if (error.message.contains("Failed to connect to",true) ||
                            error.message.contains("Unable to resolve host",true) ||
                            error.message.contains("No address associated with hostname",true))
                        errorMessage(activity, activity.getString(R.string.check_internet),0)
                    else
                        errorMessage(activity, error.message,0)
                }
            }
        }
    }






    private fun errorMessage(activity: Activity, message: String?,code:Int) {
        try {
            alertDialog = AlertDialog.Builder(activity)
            alertDialog?.setCancelable(false)
            alertDialog?.setTitle(activity.getString(R.string.alert))
            alertDialog?.setMessage(message)
            alertDialog?.setPositiveButton(activity.getString(R.string.ok)) { _, _ ->
                if (code==401)
                {
                    val intent = Intent(activity, LoginActivity::class.java)
                    activity.startActivity(intent)
                    activity.finish()
                }
                alertDialog = null
            }
            alertDialog?.show()

        } catch (ignored: Exception) {
        }

    }
}