package com.example.fieldagent.ui.addsite

import androidx.lifecycle.ViewModel
import com.example.fieldagent.data.apis.WebService
import com.example.fieldagent.data.models.responses.RoomConditionData
import com.example.fieldagent.data.models.responses.SimpleResponseData
import com.example.fieldagent.data.models.responses.UserData
import com.example.fieldagent.data.network.responseUtil.ApiResponse
import com.example.fieldagent.data.network.responseUtil.ApiUtils
import com.example.fieldagent.data.network.responseUtil.Resource
import com.example.fieldagent.di.SingleLiveEvent
import dagger.hilt.android.lifecycle.HiltViewModel
import okhttp3.RequestBody
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import javax.inject.Inject


@HiltViewModel
class AddSiteViewModel  @Inject constructor(private val webService: WebService) : ViewModel() {

    val sites by lazy { SingleLiveEvent<Resource<SimpleResponseData>>() }
    val rooms by lazy { SingleLiveEvent<Resource<RoomConditionData>>() }

    fun addSites(hashMap: HashMap<String, RequestBody>) {
        sites.value = Resource.loading()

        webService.createInspections(hashMap)
            .enqueue(object : Callback<SimpleResponseData> {

                override fun onResponse(call: Call<SimpleResponseData>,
                                        response: Response<SimpleResponseData>
                ) {
                    if (response.isSuccessful) {
                        sites.value = Resource.success(response.body())

                    } else {
                        sites.value = Resource.error(
                            ApiUtils.getError(response.code(),
                                response.errorBody()?.string()))
                    }
                }

                override fun onFailure(call: Call<SimpleResponseData>, throwable: Throwable) {
                    sites.value = Resource.error(ApiUtils.failure(throwable))
                }

            })
    }

    fun getRoomsList() {
        rooms.value = Resource.loading()

        webService.getRoomsList()
            .enqueue(object : Callback<RoomConditionData> {

                override fun onResponse(call: Call<RoomConditionData>,
                                        response: Response<RoomConditionData>
                ) {
                    if (response.isSuccessful) {
                        rooms.value = Resource.success(response.body())

                    } else {
                        rooms.value = Resource.error(
                            ApiUtils.getError(response.code(),
                                response.errorBody()?.string()))
                    }
                }

                override fun onFailure(call: Call<RoomConditionData>, throwable: Throwable) {
                    rooms.value = Resource.error(ApiUtils.failure(throwable))
                }

            })
    }


}