package com.example.fieldagent.ui.damagelist

import androidx.lifecycle.ViewModel
import com.example.fieldagent.data.apis.WebService
import com.example.fieldagent.data.models.responses.InspectionData
import com.example.fieldagent.data.models.responses.InspectionList
import com.example.fieldagent.data.models.responses.RoomConditionData
import com.example.fieldagent.data.models.responses.SimpleResponseData
import com.example.fieldagent.data.network.responseUtil.ApiUtils
import com.example.fieldagent.data.network.responseUtil.Resource
import com.example.fieldagent.di.SingleLiveEvent
import dagger.hilt.android.lifecycle.HiltViewModel
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.util.HashMap
import javax.inject.Inject


@HiltViewModel
class DamageListFragmentVM  @Inject constructor(private val webService: WebService) : ViewModel() {

    val damages by lazy { SingleLiveEvent<Resource<InspectionData>>() }
    val deleteDamage by lazy { SingleLiveEvent<Resource<SimpleResponseData>>() }


    fun getDamagesList(hashMap: HashMap<String, String>) {
        damages.value = Resource.loading()

        webService.damagesList(hashMap)
            .enqueue(object : Callback<InspectionData> {

                override fun onResponse(call: Call<InspectionData>,
                                        response: Response<InspectionData>
                ) {
                    if (response.isSuccessful) {
                        damages.value = Resource.success(response.body())

                    } else {
                        damages.value = Resource.error(
                            ApiUtils.getError(response.code(),
                                response.errorBody()?.string()))
                    }
                }

                override fun onFailure(call: Call<InspectionData>, throwable: Throwable) {
                    damages.value = Resource.error(ApiUtils.failure(throwable))
                }

            })
    }

    fun deleteInspection(id:String) {
        deleteDamage.value = Resource.loading()

        webService.deleteDamage(id)
            .enqueue(object : Callback<SimpleResponseData> {

                override fun onResponse(call: Call<SimpleResponseData>,
                                        response: Response<SimpleResponseData>
                ) {
                    if (response.isSuccessful) {
                        deleteDamage.value = Resource.success(response.body())

                    } else {
                        deleteDamage.value = Resource.error(
                            ApiUtils.getError(response.code(),
                                response.errorBody()?.string()))
                    }
                }

                override fun onFailure(call: Call<SimpleResponseData>, throwable: Throwable) {
                    deleteDamage.value = Resource.error(ApiUtils.failure(throwable))
                }

            })
    }


}